<?php

namespace Drupal\Tests\usfedgov_google_analytics\Functional\Update;

use Drupal\FunctionalTests\Update\UpdatePathTestBase;

/**
 * Tests setting updates and deletions.
 *
 * @group Update
 * @group usfedgov_google_analytics
 */
class UpdateSettingsTest extends UpdatePathTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setDatabaseDumpFiles() {
    $this->databaseDumpFiles = [
      $this->root . '/core/modules/system/tests/fixtures/update/drupal-10.3.0.filled.standard.php.gz',
      __DIR__ . '/../../../fixtures/update/usfedgov_google_analytics_8000.php',
    ];
  }

  /**
   * @covers usfedgov_google_analytics_update_20001
   * @covers usfedgov_google_analytics_update_20002
   * @covers usfedgov_google_analytics_update_20003
   */
  public function testUpdateHookN(): void {
    $old_settings = \Drupal::config('usfedgov_google_analytics.settings');

    $old_cdn = $old_settings->get('usfedgov_google_analytics__load_from_cdn');
    $this->assertSame(1, $old_cdn);

    $old_extra = $old_settings->get('usfedgov_google_analytics__settings.extra');
    $this->assertSame('1', $old_extra['sdor']);
    $this->assertSame('0', $old_extra['enhlink']);
    $this->assertSame('1', $old_extra['autotracker']);
    $this->assertSame('0', $old_extra['parallelcd']);
    $this->assertSame('12', $old_extra['cto']);
    $this->assertArrayHasKey('dclink', $old_extra);
    $this->assertArrayHasKey('aip', $old_extra);
    $this->assertArrayHasKey('forcessl', $old_extra);
    $this->assertArrayHasKey('optout', $old_extra);
    $this->assertArrayHasKey('maincd', $old_extra);

    $this->runUpdates();

    $new_settings = \Drupal::config('usfedgov_google_analytics.settings');

    $new_cdn = $new_settings->get('usfedgov_google_analytics__load_from_cdn');
    $this->assertTrue($new_cdn);

    $new_extra = $new_settings->get('usfedgov_google_analytics__settings.extra');
    // Ensure boolean settings have the correct type.
    $this->assertTrue($new_extra['sdor']);
    $this->assertFalse($new_extra['enhlink']);
    $this->assertTrue($new_extra['autotracker']);
    $this->assertFalse($new_extra['parallelcd']);
    // Ensure the cto is converted to an integer.
    $this->assertEquals(12, $new_extra['cto']);
    // Ensure obsolete settings are removed.
    $this->assertArrayNotHasKey('dclink', $new_extra);
    $this->assertArrayNotHasKey('aip', $new_extra);
    $this->assertArrayNotHasKey('forcessl', $new_extra);
    $this->assertArrayNotHasKey('optout', $new_extra);
    $this->assertArrayNotHasKey('maincd', $new_extra);
  }

}
